=================
Contributing code
=================

Do you know how to code? There's a lot of code that needs to be converted.
Each of the listings needs to be converted from BASIC to Python.

Guidelines for converting BASIC to Python
-----------------------------------------

When converting code, keep in mind that this is an educational activity, so
your best coding habits should be on display. Resist trying to be overly
"clever". Pick really clear variable names. Generally display the best
coding practice you can.

It's not *just* about the code, though. If you look at the original books,
there's two tracks on any code example - the code itself, and a bunch of
annotations describing what the code is doing. These comments are just as
important!

Lastly, keep in mind that this code was written over 35 years ago - so it's
not exactly going to be Pythonic as-is. The original code is the starting
point, not the end. You should be updating the code to be idiomatic, modern
code, not just a literal transcription.
